package com.test.test.mapper;

import java.util.List;

import com.test.test.domain.TestDatasource;

/**
 * 数据源Mapper接口
 */
public interface TestDatasourceMapper {
    /**
     * 查询数据源
     */
     TestDatasource selectTestDatasourceById(Long id);

    /**
     * 查询数据源列表
     */
     List<TestDatasource> selectTestDatasourceList();

    /**
     * 新增数据源
     */
     int insertTestDatasource(TestDatasource testDatasource);

    /**
     * 修改数据源
     */
     int updateTestDatasource(TestDatasource testDatasource);

    /**
     * 删除数据源
     */
     int deleteTestDatasourceById(Long id);

    /**
     * 批量删除数据源
     */
     int deleteTestDatasourceByIds(Long[] ids);
}
